## Module Python tmrvirus
**Module Added To The Code Generated By Tmr Virus**


## Import
```python
import tmrvirus
```

## How To Download Module Or Pip
```
pip install tmrvirus
```
-----

**Group Zalo: [Virus Team](https://zalo.me/g/nttwey011)**